@@ -57,9 +57,9 @@ def map_flexibility_signals(
             if map_negative_values_to is not None and x <= 0:
                 return map_negative_values_to
             else:
-                for percentile in percentiles:
+                for key, percentile in zip(mapping, percentiles):
                     if x <= description["{:.0%}".format(percentile)]:
-                        return mapping[percentile]
+                        return mapping[key]
                 else:
                     return None
         signals[column] = signals[column].apply(signal_mapper)
